pub struct GaussMarkov {
pub tau: Duration,
pub process_noise: f64,
pub constant: Option<f64>,
pub prev_epoch: Option<Epoch>,
pub init_sample: Option<f64>,
}Expand description
A first order Gauss-Markov process for modeling biases as described in section 5.2.4 of the NASA Best Practices for Navigation Filters (D’Souza et al.).
The process is defined by the following stochastic differential equation:
\dot{b(t)} = -1/τ * b(t) + w(t)
Programmatically, it’s calculated by sampling from b(t) ~ 𝓝(0, p_b(t)), where
p_b(t) = exp((-2 / τ) * (t - t_0)) * p_b(t_0) + s(t - t_0)
s(t - t_0) = ((q * τ) / 2) * (1 - exp((-2 / τ) * (t - t_0)))
Fields
tau: DurationThe time constant, tau gives the correlation time, or the time over which the intensity of the time correlation will fade to 1/e of its prior value. (This is sometimes incorrectly referred to as the “half-life” of the process.)
process_noise: f64constant: Option<f64>An optional constant offset on top of the noise, defaults to zero.
prev_epoch: Option<Epoch>Epoch of the previous realization, used to compute the time delta for the process noise.
init_sample: Option<f64>Sample of previous realization
Implementations
Sourceimpl GaussMarkov
impl GaussMarkov
Sourcepub fn new(tau: Duration, process_noise: f64) -> Result<Self, ConfigError>
pub fn new(tau: Duration, process_noise: f64) -> Result<Self, ConfigError>
Create a new first order Gauss-Markov process.
Arguments
tau- The time constant, tau gives the correlation time, or the time over which the intensity of the time correlation will fade to 1/e of its prior value.process_noise- process noise of the system.
Sourcepub fn default_range_km() -> Self
pub fn default_range_km() -> Self
Default Gauss Markov noise of the Deep Space Network, as per DESCANSO Chapter 3, Table 3-3. Used the range value of 60 cm over a 60 second average.
Sourcepub fn default_doppler_km_s() -> Self
pub fn default_doppler_km_s() -> Self
Default Gauss Markov noise of the Deep Space Network, as per DESCANSO Chapter 3, Table 3-3. Used the Doppler value of 0.03 mm/s over a 60 second average.